@@ -1,12 +1,13 @@
 use criterion::*;
-use rdst::bench_utils::bench_common;
-use rdst::sorts::lsb_radix_sort::lsb_radix_sort_adapter;
-use rdst::sorts::recombinating_sort::recombinating_sort;
-use rdst::sorts::regions_sort::regions_sort;
-use rdst::sorts::scanning_radix_sort::scanning_radix_sort;
+use rdst::bench_utils::{bench_common, bench_comparative};
+use rdst::sorts::comparative_sort::comparative_sort;
+use rdst::sorts::lsb_sort::lsb_sort_adapter;
+use rdst::sorts::recombinating_sort::recombinating_sort_adapter;
+use rdst::sorts::regions_sort::regions_sort_adapter;
+use rdst::sorts::scanning_sort::scanning_sort_adapter;
 use rdst::sorts::ska_sort::ska_sort_adapter;
 use rdst::test_utils::NumericTest;
-use rdst::tuning_parameters::TuningParameters;
+use rdst::tuner::DefaultTuner;
 use rdst::utils::*;
 
 fn tune_counts(c: &mut Criterion) {
@@ -38,39 +39,39 @@ where
         (
             "regions_sort",
             Box::new(|mut input| {
-                let tuning = TuningParameters::new(4);
-                regions_sort(&tuning, &mut input, 3);
+                let tuner = DefaultTuner {};
+                regions_sort_adapter(&tuner, true, &mut input, 3);
                 black_box(input);
             }),
         ),
         (
-            "scanning_radix_sort",
+            "scanning_sort",
             Box::new(|mut input| {
-                let tuning = TuningParameters::new(4);
-                scanning_radix_sort(&tuning, &mut input, 3, true);
+                let tuner = DefaultTuner {};
+                scanning_sort_adapter(&tuner, false, &mut input, 3);
                 black_box(input);
             }),
         ),
         (
-            "lsb_radix_sort",
+            "lsb_sort",
             Box::new(|mut input| {
-                lsb_radix_sort_adapter(&mut input, 0, 3);
+                lsb_sort_adapter(&mut input, 0, 3);
                 black_box(input);
             }),
         ),
         (
             "ska_sort",
             Box::new(|mut input| {
-                let tuning = TuningParameters::new(4);
-                ska_sort_adapter(&tuning, true, &mut input, 3);
+                let tuner = DefaultTuner {};
+                ska_sort_adapter(&tuner, true, &mut input, 3);
                 black_box(input);
             }),
         ),
         (
             "recombinating_sort",
             Box::new(|mut input| {
-                let tuning = TuningParameters::new(4);
-                recombinating_sort(&tuning, &mut input, 3);
+                let tuner = DefaultTuner {};
+                recombinating_sort_adapter(&tuner, false, &mut input, 3);
                 black_box(input);
             }),
         ),
@@ -95,12 +96,61 @@ fn tune_sort_u64_bimodal(c: &mut Criterion) {
     tune_sort_common(c, 32u64, "sort_u64_bimodal");
 }
 
+fn tune_sort_comparative<T>(c: &mut Criterion, shift: T, name_suffix: &str)
+where
+    T: NumericTest<T>,
+{
+    let tests: Vec<(&str, Box<dyn Fn(Vec<_>)>)> = vec![
+        (
+            "lsb_sort",
+            Box::new(|mut input| {
+                lsb_sort_adapter(&mut input, 0, 3);
+                black_box(input);
+            }),
+        ),
+        (
+            "comparative_sort",
+            Box::new(|mut input| {
+                comparative_sort(&mut input, 3);
+                black_box(input);
+            }),
+        ),
+    ];
+
+    bench_comparative(
+        c,
+        shift,
+        &("tune_comparative_".to_owned() + name_suffix),
+        tests,
+    );
+}
+
+fn tune_sort_comparative_u32(c: &mut Criterion) {
+    tune_sort_comparative(c, 0u32, "sort_u32");
+}
+
+fn tune_sort_comparative_u64(c: &mut Criterion) {
+    tune_sort_comparative(c, 0u64, "sort_u64");
+}
+
+fn tune_sort_comparative_u32_bimodal(c: &mut Criterion) {
+    tune_sort_comparative(c, 16u32, "sort_u32_bimodal");
+}
+
+fn tune_sort_comparative_u64_bimodal(c: &mut Criterion) {
+    tune_sort_comparative(c, 32u64, "sort_u64_bimodal");
+}
+
 criterion_group!(
     tuning_parameters,
     tune_counts,
     tune_sort_u32,
     tune_sort_u64,
     tune_sort_u32_bimodal,
-    tune_sort_u64_bimodal
+    tune_sort_u64_bimodal,
+    tune_sort_comparative_u32,
+    tune_sort_comparative_u64,
+    tune_sort_comparative_u32_bimodal,
+    tune_sort_comparative_u64_bimodal,
 );
 criterion_main!(tuning_parameters);
