@@ -1,6 +1,7 @@
-pub mod lsb_radix_sort;
+pub mod comparative_sort;
+pub mod lsb_sort;
 pub mod out_of_place_sort;
 pub mod recombinating_sort;
 pub mod regions_sort;
-pub mod scanning_radix_sort;
+pub mod scanning_sort;
 pub mod ska_sort;
