@@ -1,33 +1,35 @@
 use crate::director::director;
-use crate::tuning_parameters::TuningParameters;
+use crate::tuner::Tuner;
 use crate::utils::*;
 use crate::RadixKey;
-use arbitrary_chunks::ArbitraryChunks;
 
 // Based upon (with modifications):
 // https://probablydance.com/2016/12/27/i-wrote-a-faster-sorting-algorithm/
-pub fn ska_sort<T>(bucket: &mut [T], counts: &[usize], level: usize)
+pub fn ska_sort<T>(bucket: &mut [T], prefix_sums: &mut [usize], end_offsets: &[usize], level: usize)
 where
     T: RadixKey + Sized + Send + Copy + Sync,
 {
-    let mut prefix_sums = get_prefix_sums(counts);
-    let mut end_offsets = [0usize; 256];
-
-    end_offsets[0..255].copy_from_slice(&prefix_sums[1..256]);
-    end_offsets[255] = counts[255] + prefix_sums[255];
-
     let mut finished = 1;
     let mut finished_map = [false; 256];
     let mut largest = 0;
     let mut largest_index = 0;
 
-    for (i, c) in counts.iter().enumerate() {
-        if *c > largest {
-            largest = *c;
+    for i in 0..256 {
+        let rem = end_offsets[i] - prefix_sums[i];
+        if rem == 0 {
+            finished_map[i] = true;
+            finished += 1;
+        } else if rem > largest {
+            largest = rem;
             largest_index = i;
         }
     }
 
+    if largest == bucket.len() {
+        // Already sorted
+        return;
+    }
+
     finished_map[largest_index] = true;
 
     while finished != 256 {
@@ -49,8 +51,12 @@ where
 }
 
 #[allow(dead_code)]
-pub fn ska_sort_adapter<T>(tuning: &TuningParameters, inplace: bool, bucket: &mut [T], level: usize)
-where
+pub fn ska_sort_adapter<T>(
+    tuner: &(dyn Tuner + Send + Sync),
+    in_place: bool,
+    bucket: &mut [T],
+    level: usize,
+) where
     T: RadixKey + Sized + Send + Copy + Sync,
 {
     let (counts, level) = if let Some(s) = get_counts_and_level_descending(bucket, level, 0, false)
@@ -60,32 +66,31 @@ where
         return;
     };
 
-    ska_sort(bucket, &counts, level);
+    let plateaus = detect_plateaus(bucket, level);
+    let (mut prefix_sums, end_offsets) = apply_plateaus(bucket, &counts, &plateaus);
+
+    ska_sort(bucket, &mut prefix_sums, &end_offsets, level);
 
     if level == 0 {
         return;
     }
 
-    let len = bucket.len();
-
-    bucket
-        .arbitrary_chunks_mut(counts.to_vec())
-        .for_each(|chunk| director(tuning, inplace, chunk, len, level - 1));
+    director(tuner, in_place, bucket, counts.to_vec(), level - 1);
 }
 
 #[cfg(test)]
 mod tests {
     use crate::sorts::ska_sort::ska_sort_adapter;
     use crate::test_utils::{sort_comparison_suite, NumericTest};
-    use crate::tuning_parameters::TuningParameters;
+    use crate::tuner::DefaultTuner;
 
     fn test_ska_sort_adapter<T>(shift: T)
     where
         T: NumericTest<T>,
     {
-        let tuning = TuningParameters::new(T::LEVELS);
+        let tuner = DefaultTuner {};
         sort_comparison_suite(shift, |inputs| {
-            ska_sort_adapter(&tuning, true, inputs, T::LEVELS - 1)
+            ska_sort_adapter(&tuner, true, inputs, T::LEVELS - 1)
         });
     }
 
